#
# spec file for package ghc-djot
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name djot
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.1.2.2
Release:        1.5
Summary:        Parser and renderer for djot light markup syntax
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  chrpath
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-doclayout-devel
BuildRequires:  ghc-doclayout-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-template-haskell-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-prof
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-tasty-quickcheck-prof
%endif

%description
Djot (<https://djot.net>) is a light markup language. This package provides a
data structure to represent djot documents, a very fast parser, and functions
to render a parsed document as HTML and as djot.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE
%{_bindir}/djoths

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sat Oct  5 2024 Peter Simons <psimons@suse.com>
- Update djot to version 0.1.2.2.
  [#]# 0.1.2.2 -- 2024-10-04
  * Allow list items with blank lines between divs (#10).
  * Fix parsing of indented tables (#8).
* Mon Jun 24 2024 Peter Simons <psimons@suse.com>
- Update djot to version 0.1.2.1.
  [#]# 0.1.2.1 -- 2024-06-24
  * Djot writer: include separator line in table when the table has
    non-default alignments but no header (#7).
* Sat May 11 2024 Peter Simons <psimons@suse.com>
- Update djot to version 0.1.2.
  [#]# 0.1.2 -- 2024-05-10
  * Allow `_` in symbols (see jgm/djot#296).
  * Add Lift derivations to AST datatypes (#5, Gideon Farrell) [API change].
* Mon Mar 18 2024 Peter Simons <psimons@suse.com>
- Update djot to version 0.1.1.3.
  [#]# 0.1.1.3 -- 2024-03-17
  * Ensure that tables end when we hit a blank line (#4).
  * Fix parsing of table immediately after list (#4).
* Thu Mar 14 2024 Peter Simons <psimons@suse.com>
- Update djot to version 0.1.1.2.
  [#]# 0.1.1.2 -- 2024-03-14
  * Fix bug parsing regular paragraphs after list (#4).
* Mon Mar  4 2024 Peter Simons <psimons@suse.com>
- Update djot to version 0.1.1.1.
  [#]# 0.1.1.1 -- 2024-03-03
  * Revert "Djot.Blocks: use ByteString directly in `toIdentifier` (#1)"
    This caused problems for UTF-8 sequences that contained the
    byte 0xa0, which B8.words treats as a space character.
  * AST: avoid using B8.words in normalizeLabel.
  * Avoid using isSpace in attribute parsing. isSpace matches a byte 0x0a,
    which can break up a UTF-8 sequence. Limit to ASCII whitespace.
  * Add test with UTF-8 identifier. See jgm/pandoc#9541.
* Fri Mar  1 2024 Peter Simons <psimons@suse.com>
- Update djot to version 0.1.1.0.
  [#]# 0.1.1.0 -- 2024-02-29
  * Add Data instances to everything in the AST [API change].
  * Ensure that block attributes are indented on subsequent lines (#2).
  * Djot.Blocks: use ByteString directly in `toIdentifier` (#1,
    Vaibhav Sagar).
* Thu Feb 15 2024 Peter Simons <psimons@suse.com>
- Add djot at version 0.1.0.0.
